#!/bin/sh
# Restart with tclsh \
exec tclsh "$0" "$@"

set next_rnd ""

# Random number generator with a Gaussian distribution between $min and $max.
proc sample {min max} {
    global next_rnd

    if {$next_rnd eq ""} {
        set r1 [expr {sqrt(-2 * log(rand()))}]
        set r2 [expr {6.28318530718 * rand()}]
        set factor [expr {($max - $min) * 0.5}]
        set offset [expr {($max + $min) * 0.5}]
        set val      [expr {int($r1 * cos($r2) * $factor + $offset)}]
        set next_rnd [expr {int($r1 * sin($r2) * $factor + $offset)}]
    } else {
        set val $next_rnd
        set next_rnd ""
    }

    if {$val < 0} {set val 0} elseif {$val > 255} {set val 255}

    return $val
}

# Handler for incoming data.
proc incoming {chan} {
    global min max

}

if {[llength $argv] != 3} {
    # Bad command line.
    puts stderr "Usage: randpres.tcl delay min max"
    exit 1
} else {
    # Scan arguments.
    foreach {delay min max} $argv {}
}

fconfigure stdin -blocking 0

# Seed random number generator.
expr {srand([clock clicks -milliseconds])}

# Loop until SIGTERM.
while {1} {
    # Generate packet.
    puts "PRESSURE [sample $min $max] 0 0 0"
    #puts "PRESSURE [sample $min $max] [sample $min $max]\
                   #[sample $min $max] [sample $min $max]"
    
    # Wait a bit.
    after $delay

    # Check for input.
    if {[eof stdin]} {
        exit
    } else {
        scan [read stdin] "%d %d" min max
    }
}

# vim: set ts=4 sts=4 sw=4 tw=80 et:
